@@ -440,8 +440,8 @@ def main():
         load_file(main_window, augCanvas, update, config, loadthread,
                   filename=sys.argv[1])
     else:
-        gt.pop_plot(0, 0, augCanvas.spectplot, augCanvas.ms)
-        gt.pop_plot(0, 0, augCanvas.chromplot, augCanvas.chrom)
+        gt.pop_plot([], [], augCanvas.spectplot, augCanvas.ms)
+        gt.pop_plot([], [], augCanvas.chromplot, augCanvas.chrom)
 
     main_window.show()
     sys.exit(app.exec_())
