@@ -66,7 +66,7 @@ def update_drlspectrum(ds, drls, drlspectrum):
 
     names, times, intensities = drl.get_daughterset(ds, drls)
     drlspectrum.clear()
-    gt.pop_plot(0, 0, drlspectrum, drls['graphlabels'])
+    gt.pop_plot([], [], drlspectrum, drls['graphlabels'])
     drlspectrum.axvline(0, 0, 0.9, color="#FF000088", linestyle=":")
 
     if drls['cutoff'].value() != 0:
@@ -415,7 +415,7 @@ def print_graph(ds, drls):
     printfig = Figure(figsize=(5, 2), dpi=100)
     printplot = printfig.add_subplot(111)
     printcanvas = FigureCanvas(printfig)
-    gt.pop_plot(0, 0, printplot, drls['graphlabels'])
+    gt.pop_plot([], [], printplot, drls['graphlabels'])
     update_drlspectrum(ds, drls, printplot)
     widget = QtWidgets.QDialog(None, windowTitle='Print preview')
     layout = QtWidgets.QVBoxLayout(widget)
@@ -571,7 +571,7 @@ def main_window(parent, augCanvas, update_signal):
         graph_canvas.setAutoFillBackground(False)
         gt.pan_factory(chromplot)
         gt.zoom_factory(chromplot, 1.15)
-        gt.pop_plot(0, 0, chromplot, drls['graphlabels'])
+        gt.pop_plot([], [], chromplot, drls['graphlabels'])
 
         dcolums = ["Name"]
         for i in range(drls['cors'].value()):
