@@ -379,11 +379,6 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
         peakline = np.empty([len(maxargs)], dtype=[('x', np.float32), ('y', np.float32)])
         peakline['x'], peakline['y'] = xdata[maxargs], ydata[maxargs]
         peaks.append(peakline)
-    peaks = np.concatenate(peaks)
-
-    s_peaks = sub_peaks(peaks, msdata['texts'],
-                        np.diff(ms_spec.get_xlim()),
-                        np.diff(ms_spec.get_ylim()))
 
     # delete objects from the spectra
     for intensity in msdata['annotation']:
@@ -391,6 +386,14 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
     # remove them from tracking
     msdata['annotation'].clear()
 
+    if len(peaks) == 0:
+        return
+    peaks = np.concatenate(peaks)
+
+    s_peaks = sub_peaks(peaks, msdata['texts'],
+                        np.diff(ms_spec.get_xlim()),
+                        np.diff(ms_spec.get_ylim()))
+
     dispints = cf.settings().value("view/intensities", type=bool)
     for peak in s_peaks:
         annotation = '{0:.2f}\n{1: .2e}'.format(peak[0], peak[1])\
@@ -403,8 +406,9 @@ def ann_spec(ms_spec, msdata, ann_limit=0.01):
 
 def pop_plot(xdata, ydata, plot, plot_data, colornum=0, legend=None, annotate=True):
     """Define and populate plot"""
-    plot.plot(xdata, ydata, linewidth=1, color=(
-        colors[colornum % len(colors)]/255), label=legend)
+    if len(xdata):
+        plot.plot(xdata, ydata, linewidth=1, color=(
+            colors[colornum % len(colors)]/255), label=legend)
     plot.set_title(plot_data['name'], loc="right")
     plot.set_xlabel(plot_data['xlabel'])
     plot.set_ylabel(plot_data['ylabel'])
